periodhist(X, dfreq=FALSE, vt, drop=TRUE)Rcapture-package
for a description of the accepted formats).X has one row per unit. If TRUE, it
indicates that the matrix X contains frequencies in its last column.drop must be set to FALSE.drop=TRUE (the default), the number of rows
of this matrix is in fact $2^I-1$ minus the number of unobserved capture histories.periodhist function.
If a data matrix produced by the periodhist function is given as an argument to a dfreq argument must be set to TRUE.openpdata(mvole)
mvole.op<-periodhist(mvole,vt=rep(5,6))
openp(mvole.op, dfreq=TRUE)Run the code above in your browser using DataLab