periodhist(X, dfreq=FALSE, vt, drop=TRUE)Rcapture-package for a description of the accepted formats).X has one row per unit. If TRUE, it indicates that the matrix X contains frequencies in its last column.drop must be set to FALSE.periodhist function.
If a data matrix produced by the periodhist function is given in argument to an model fiting function, the dfreq argument must be set to TRUE.openpdata(mvole)
mvole.op<-periodhist(mvole,vt=rep(5,6))
openp(mvole.op, dfreq=TRUE)Run the code above in your browser using DataLab