periodhist(X, dfreq=FALSE, vt)X. By default, it is set to FALSE, which means that X has one row per unit. If it is set to TRUE, then the matrix X contains frequencies in its last column.periodhist function is given in argument to an openp function, the dfreq argument must be set to TRUE.openpdata(mvole)
mvole.op<-periodhist(mvole,vt=rep(5,6))
openp(mvole.op, dfreq=TRUE)Run the code above in your browser using DataLab